import logoSvg from '../../assets/logo.svg';
import copySvg from '../../assets/copy.svg';
import { Button, Col, Grid, Row } from 'antd';
import styles from './index.less';
import classNames from 'classnames';

interface IAnswerProps {
  answerValue: string;
  isShowRetry?: boolean;
}

const { useBreakpoint } = Grid;

const Answer = (props: IAnswerProps) => {
  const { answerValue, isShowRetry } = props;

  const screens = useBreakpoint();
  const isMobile = screens.xs;

  return (
    <Col span={24}>
      <Row>
        <Col span={24}>
          <p className={styles.question} style={{ marginTop: isMobile ? '20px' : '40px' }}>
            <img src={logoSvg} alt="" className={styles.question_img} />
            <span
              className={classNames(isMobile && styles.mobile_question_span, styles.question_span)}
              style={{ marginLeft: isMobile ? '8px' : '16px' }}
            >
              回答如下：
            </span>
          </p>
        </Col>
        <Col span={24} className={styles.chat}>
          <div className={classNames(styles.answer, isMobile && styles.mobile_answer)}>
            <div className={styles.answer}>
              {!answerValue ? (
                <p style={{ color: '#666666' }}>请耐心等待3-5秒~</p>
              ) : (
                <p dangerouslySetInnerHTML={{ __html: answerValue }}></p>
              )}
            </div>
            {!isMobile && answerValue && (
              <p className={styles.copyAnswer} onClick={() => {}}>
                <img src={copySvg} alt="" />
                <span>复制回答</span>
              </p>
            )}
          </div>
          {isShowRetry && !isMobile && <Button className={styles.chat_retry}>重试</Button>}
        </Col>
        <Col>
          {isMobile && answerValue && (
            <Row justify={'center'} className={styles.mobile_button}>
              <Button className={styles.mobile_copyAnswer}>
                <img src={copySvg} alt="" />
                <span>复制回答</span>
              </Button>
              <Button className={styles.mobile_chat_retry}>重试</Button>
            </Row>
          )}
        </Col>
      </Row>
    </Col>
  );
};

export default Answer;
